@@ -1,16 +1,17 @@
 #include <stdarg.h>
+#include "../visibility.h"
 
-int answer()
+EXPORT int answer()
 {
     return 42;
 }
 
-int sum(int a, int b, int c)
+EXPORT int sum(int a, int b, int c)
 {
     return a + b + c;
 }
 
-void sum_primitive_types(
+EXPORT void sum_primitive_types(
     unsigned char a, signed char b,
     unsigned short c, signed short d,
     unsigned long e, signed long f,
@@ -32,13 +33,13 @@ struct test_struct
     int *p;
 };
 
-int sum_struct(struct test_struct s)
+EXPORT int sum_struct(struct test_struct s)
 {
     *s.p = s.b + s.s + s.i + s.j + s.f + s.d + *(s.p);
     return *s.p;
 }
 
-int sum_array(int ary[4])
+EXPORT int sum_array(int ary[4])
 {
     int sum = 0;
     for (int i = 0; i < 4; i++)
@@ -48,7 +49,7 @@ int sum_array(int ary[4])
     return sum;
 }
 
-int sum_variadic(int count, ...)
+EXPORT int sum_variadic(int count, ...)
 {
     va_list ap;
     int j;
@@ -64,7 +65,7 @@ int sum_variadic(int count, ...)
     return sum;
 }
 
-struct test_struct make_struct(char b, short s, int i, long long j, float f, double d, void *p)
+EXPORT struct test_struct make_struct(char b, short s, int i, long long j, float f, double d, void *p)
 {
     struct test_struct t;
     t.b = b;
