@@ -2,23 +2,30 @@
 
 # This file can be executed from the root of the working copy
 #
-# $ ./spec/debug/test.sh
+# $ ./spec/debug/test.sh [lldb|gdb]
+#
+# The argument selects one of the debuggers, defaulting to LLDB.
 #
 # It will use the ./spec/debug/driver.cr program to execute
 # the files explicitly listed at the end of this file.
 #
-# Those files have magic comments to build a script for an lldb session
+# Those files have magic comments to build a script for a debugger session
 # and a FileCheck file with assertions over that session.
 #
-# In ./tmp/debug you can find a dump of the session and the assertion file.
-#
 # The magic comments interpreted by the driver are:
 #
-#   * # lldb-command:
-#   * # lldb-check:
+# * `# print: expr`
+#   Prints the given expression in the debugger, e.g. a variable.
+# * `# check: pattern`
+#   Asserts that the debugger output matches the given FileCheck pattern.
+# * `# xxx-check: pattern`
+#   Like above, but only effective if `xxx` matches the debugger name. Has no
+#   effect for the other debuggers.
 #
 # These comments should then be followed by a call to `debugger` which sets up
 # the actual breakpoint.
+#
+# In ./tmp/debug you can find a dump of the session and the assertion file.
 
 set -euo pipefail
 
@@ -27,10 +34,12 @@ SCRIPT_ROOT="$(dirname "$SCRIPT_PATH")"
 
 BUILD_DIR=$SCRIPT_ROOT/../../.build
 crystal=${CRYSTAL_SPEC_COMPILER_BIN:-$SCRIPT_ROOT/../../bin/crystal}
+debugger=${1:-lldb}
 driver=$BUILD_DIR/debug_driver
 mkdir -p $BUILD_DIR
 "$crystal" build $SCRIPT_ROOT/driver.cr -o $driver
 
-$driver $SCRIPT_ROOT/top_level.cr
-$driver $SCRIPT_ROOT/strings.cr
-$driver $SCRIPT_ROOT/blocks.cr
+$driver $SCRIPT_ROOT/top_level.cr $debugger
+$driver $SCRIPT_ROOT/strings.cr $debugger
+$driver $SCRIPT_ROOT/arrays.cr $debugger
+$driver $SCRIPT_ROOT/blocks.cr $debugger
